<!--
SPDX-FileCopyrightText: 2020 IntelMQ Team

SPDX-License-Identifier: AGPL-3.0-or-later
-->

# Contributing Hints

## CSS

Please apply changes only to the LESS-files and convert them to CSS.

## Licenses

If external components are added or updated, make sure the copyright notices are complete. Check the `debian/copyright` file, which maps files to licenses and the `LICENSES` directory where all licenses used by IntelMQ Manager must be stored.

## Code submissions and workflow

Please see the developer guide of IntelMQ for a complete description and workflow: https://github.com/certtools/intelmq/blob/master/docs/Developers-Guide.md#code-submission-rules
